[Rivet-svn] rivet: 5 new changesets

Rivet Mercurial rivet at projects.hepforge.org
Fri Nov 17 01:30:02 GMT 2017


details:   https://rivet.hepforge.org/hg/rivet/rev/29e70fe76ca6
branches:  
changeset: 6139:29e70fe76ca6
user:      Andy Buckley <andy at insectnation.org>
date:      Thu Nov 16 13:10:16 2017 +0000
description:
Improvements to DISKinematics interface, and porting dijet photoproduction analysis to use it

details:   https://rivet.hepforge.org/hg/rivet/rev/4db29d2d5cf8
branches:  
changeset: 6140:4db29d2d5cf8
user:      Andy Buckley <andy at insectnation.org>
date:      Thu Nov 16 13:24:50 2017 +0000
description:
More DIS analysis and projection updates

details:   https://rivet.hepforge.org/hg/rivet/rev/c77d6320c9bb
branches:  
changeset: 6141:c77d6320c9bb
user:      Andy Buckley <andy at insectnation.org>
date:      Thu Nov 16 13:25:31 2017 +0000
description:
Remove commented-out block

details:   https://rivet.hepforge.org/hg/rivet/rev/70497ef3dc25
branches:  
changeset: 6142:70497ef3dc25
user:      Andy Buckley <andy at insectnation.org>
date:      Thu Nov 16 15:24:04 2017 +0000
description:
DIS lepton -> final-state definition

details:   https://rivet.hepforge.org/hg/rivet/rev/23bb33df36de
branches:  
changeset: 6143:23bb33df36de
user:      Andy Buckley <andy at insectnation.org>
date:      Fri Nov 17 01:23:06 2017 +0000
description:
Various improvements to DISKinematics, DISLepton, and the ZEUS 2001 analysis.

diffs (truncated from 422 to 50 lines):

--- a/ChangeLog	Wed Nov 15 21:50:43 2017 +0000
+++ b/ChangeLog	Fri Nov 17 01:23:06 2017 +0000
@@ -1,3 +1,7 @@
+2017-11-17  Andy Buckley  <andy.buckley at cern.ch>
+
+	* Various improvements to DISKinematics, DISLepton, and the ZEUS 2001 analysis.
+
 2017-11-06  Andy Buckley  <andy.buckley at cern.ch>
 
 	* Extend AOPath regex to allow dots and underscores in weight names.
--- a/analyses/pluginHERA/ZEUS_2001_S4815815.cc	Wed Nov 15 21:50:43 2017 +0000
+++ b/analyses/pluginHERA/ZEUS_2001_S4815815.cc	Fri Nov 17 01:23:06 2017 +0000
@@ -22,18 +22,18 @@
     /// Constructor
     DEFAULT_RIVET_ANALYSIS_CTOR(ZEUS_2001_S4815815);
 
+
     /// @name Analysis methods
     //@{
 
     // Book projections and histograms
     void init() {
 
+      // Projections
       /// @todo Acceptance
       FinalState fs;
       declare(FastJets(fs, FastJets::KT, 1.0), "Jets"); //< R=1 checked with Matt Wing
-
-      // Projections
-      declare(DISLepton(), "Lepton");
+      declare(DISKinematics(), "Kinematics");
 
       // Table 1
       _h_costh[0] = bookHisto1D(1, 1, 1);
@@ -71,14 +71,13 @@
     // Do the analysis
     void analyze(const Event& event) {
 
-      // Determine event orientation, since coord system is for +z = proton direction
-      const ParticlePair bs = event.beams();
-      if (bs.first.pid() != PID::POSITRON && bs.second.pid() != PID::POSITRON) vetoEvent;
-      const Particle& bpositron = (bs.first.pid() == PID::POSITRON ? bs.first : bs.second);
-      if (bs.first.pid() != PID::PROTON && bs.second.pid() != PID::PROTON) vetoEvent;
-      const Particle& bproton = (bs.first.pid() == PID::PROTON) ? bs.first : bs.second;
-      const int orientation = sign(bproton.momentum().pz());
-      MSG_DEBUG("Beam proton = " << bproton.mom() << " GeV => orientation = " << orientation);
+      // Determine kinematics, including event orientation since ZEUS coord system is for +z = proton direction
+      const DISKinematics& kin = apply<DISKinematics>(event, "Kinematics");
+      const int orientation = kin.orientation();
+


More information about the Rivet-svn mailing list